range_limit: Calculate state range limit

Description Usage Arguments Examples

View source: R/range_limit.R

Description

This function calculates the south range limit of boreal and the north range limit of temperate states in a specific landscape configuration

Usage

1
range_limit(land, nRow, nCol, occup)

Arguments

land

vector, one element of the run_model output

nRow

numeric, number of rows of the landscape. Value is found in the output list from the run_model function

nCol

numeric, number of columns of the landscape. Value is found in the output list from the run_model function

occup

numeric between 0 and 1. The value determines the minimum occupancy a row of the landscape must be occupied by a specific forest state to be considered part of the state range

Examples

1
2
3
4
5
## Not run: 
lands <- run_model(steps = 10, initLand)
range_limit(lands[['land_TX']], lands[['nRow']], lands[['nCol']], occup = .7)

## End(Not run)

willvieira/STManaged documentation built on Sept. 4, 2020, 2:26 p.m.