Description Usage Arguments Examples
This function calculates the south range limit of boreal and the north range limit of temperate states in a specific landscape configuration
1 | range_limit(land, nRow, nCol, occup)
|
land |
vector, one element of the |
nRow |
numeric, number of rows of the landscape. Value is found in the output list from the |
nCol |
numeric, number of columns of the landscape. Value is found in the output list from the |
occup |
numeric between 0 and 1. The value determines the minimum occupancy a row of the landscape must be occupied by a specific forest state to be considered part of the state range |
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.